package net.monarchpass.piecannon;

import java.net.URI;

import java.io.File;
import java.util.List;
import java.util.ArrayList;

import org.freedesktop.BaseDirectory;

import lombok.extern.java.Log;
import java.util.logging.Level;

import net.monarchpass.piecannon.util.ServerFactory;

@Log
public class App {
    public static void main (final String... args) throws Exception {
        final File serversJson = getServersJson();
        final PieCannon cannon = new PieCannon();
        final List<Server> servers = cannon.loadServersFrom(serversJson);
        log.log(Level.INFO, "{0} servers loaded from {1}", new Object[] {
            servers.size(), serversJson
        });
        
        if (servers.isEmpty()) {
            log.log(Level.SEVERE, "No servers defined, please define at least one in {0}", serversJson);
            System.exit(1);
        }
        
        final Server server = cannon.selectServer();
        log.log(Level.INFO, "Randomly selected server: {0}", server.getLabel());
        
        if (args.length == 0) {
            log.log(Level.SEVERE, "No filename provided");
            System.exit(1);
        }
        
        final File source = new File(args[0]);
        if (!source.exists()) {
            log.log(Level.SEVERE, "No such file: {0}", source);
            System.exit(1);
        }
        
        final URI result = server.upload(source);
        System.out.println(result);
    }
 
    public static File getServersJson () {
        return new File(getDataDirectory(), "servers.json");
    }
    
    public static File getDataDirectory () {
        return new File(BaseDirectory.get(BaseDirectory.XDG_DATA_HOME), "piecannon");
    }
}
